%define	build_plf 0

%if %{mdkversion} < 200610
%define	build_dbus 0
%else
%define	build_dbus 1
%endif

%define	build_perl 1
%define	build_python 1
%define	build_tcl 1

%{?_with_plf: %{expand: %%global build_plf 1}}

%{?_without_dbus: %{expand: %%global build_dbus 0}} 
%{?_with_dbus: %{expand: %%global build_dbus 1}} 

%{?_without_perl: %{expand: %%global build_perl 0}} 
%{?_with_perl: %{expand: %%global build_perl 1}} 

%{?_without_python: %{expand: %%global build_python 0}} 
%{?_with_python: %{expand: %%global build_python 1}} 

%{?_without_tcl: %{expand: %%global build_tcl 0}} 
%{?_with_tcl: %{expand: %%global build_tcl 1}} 


%define	name	xchat
%define	version	2.8.0
%define	rel	1
%define	main_summary	Graphical IRC client
%define	perl_version	%(rpm -q --qf '%%{epoch}:%%{VERSION}' perl)
%define	iconname	xchat.png 

%if %build_plf
%define	distsuffix plf
%endif 

Name:		%{name}
Version:	%{version}
Release:	%mkrel %{rel}
Summary:	%{main_summary}
Group:		Networking/IRC
License:	GPL
Url:		http://www.xchat.org
Buildroot:	%{_tmppath}/%{name}-%{version}-%{release}-root

Source:		http://www.xchat.org/files/source/2.6/%{name}-%{version}.tar.bz2 
Patch0:		xchat-2.6.4-ctcp_version.patch.bz2
Patch2:		xchat-2.0.8-nicksuffix.patch.bz2
Patch3:		xchat-2.6.1-servlist.patch.bz2
Patch4:		xchat-2.4.1-firefox.patch.bz2
Patch5:		xchat-2.6.8-latin9.patch
Patch6:		xc280-fix-back.diff

Obsoletes:	xchat-dbus < 2.6.8
Provides:	xchat-dbus = %version-%release

BuildRequires:	bison
Buildrequires:	gtk+2-devel
BuildRequires:	openssl-devel
BuildRequires:	ImageMagick
BuildRequires:	GConf2
BuildRequires:	desktop-file-utils
BuildRequires:	libsexy-devel
BuildRequires:	autoconf2.5
BuildRequires:	gettext-devel
%if %build_perl
BuildRequires:	perl-devel
%endif
%if %build_python
BuildRequires:	python-devel
%endif
%if %build_tcl
BuildRequires:	tcl
%if %{mdkversion} >= 200610
BuildRequires:	tcl-devel
%endif
%endif
%if %build_dbus
BuildRequires:	dbus-glib-devel 
BuildRequires:	libtool
%endif
%if %build_plf
BuildRequires:	socks5-devel
%endif

%description
X-Chat is yet another IRC client for the X Window System, using the Gtk+
toolkit. It is pretty easy to use compared to the other Gtk+ IRC clients and
the interface is quite nicely designed.

Build Options:
--with plf       Enable SOCKS5 support (need to download from PLF)
--without dbus   Disable DBus plugin
--without perl   Disable Perl plugin 
--without python Disable Python plugin 
--without tcl    Disable TCL plugin 

%package devel
Summary:	XChat header for plugin development
Group:		Development/C

%description devel
This package contains xchat-plugin.h needed to build external plugins.

%package perl
Summary:	XChat Perl plugin
Group:		Networking/IRC
Requires:	%{name} = %{version}
Requires:	perl-base = %perl_version

%description perl
Provides Perl scripting capability to XChat.

%package python
Summary:	XChat Python plugin
Group:		Networking/IRC
Requires:	%{name} = %{version}

%description python
Provides Python scripting capability to XChat.

%package tcl
Summary:	XChat TCL plugin
Group:		Networking/IRC
Requires:	%{name} = %{version}

%description tcl
Provides tcl scripting capability to XChat.


%prep
%setup -q
%patch0
%patch2 -p1
%patch3 -p0 -b .default_server
%patch4 -p0 -b .firefox
%patch5 -p1 -b .latin9
%patch6 -p1 -b .fixback

%build

%if %{mdkversion} < 1010
%define	__libtoolize /bin/true
%endif

aclocal
autoconf-2.5x
#Yes this is bad
touch NEWS ABOUT-NLS
automake

%configure2_5x  --enable-openssl \
		--enable-ipv6 \
		--enable-hebrew \
		--enable-japanese-conv \
%if %build_perl
		--enable-perl \
%else
		--disable-perl \
%endif
%if %build_dbus
		--enable-dbus \
%else
		--disable-dbus \
%endif
%if %build_python
		--enable-python \
%else
		--disable-python \
%endif
%if %build_tcl
		--enable-tcl=%{_libdir} \
%else
	        --disable-tcl
%endif
		--disable-textfe \
		--enable-spell=libsexy \
%if %build_plf
		--enable-socks
%endif

%make

%install
rm -rf $RPM_BUILD_ROOT
%makeinstall_std

%find_lang xchat

mkdir -p %{buildroot}{%{_miconsdir},%{_iconsdir},%{_liconsdir},%{_menudir}}
convert xchat.png -geometry 48x48 %{buildroot}%{_liconsdir}/%{iconname}
convert xchat.png -geometry 32x32 %{buildroot}%{_iconsdir}/%{iconname}
convert xchat.png -geometry 16x16 %{buildroot}%{_miconsdir}/%{iconname}
 
cat > $RPM_BUILD_ROOT%{_menudir}/%{name} << EOF
?package(%name): needs="x11" \
	section="Internet/Chat" \
	title="Xchat" \
	longtitle="%{main_summary}" \
	command="%{_bindir}/%{name}" \
	icon="%{name}.png" \
	xdg="true"
EOF

desktop-file-install --vendor="" \
  --remove-category="Application" \
  --add-category="GTK" \
  --add-category="IRCClient" \
  --add-category="X-Mandrakelinux-Internet-Chat" \
  --dir $RPM_BUILD_ROOT%{_datadir}/applications $RPM_BUILD_ROOT%{_datadir}/applications/*

mkdir -p %{buildroot}%{_includedir}
cp plugins/xchat-plugin.h %{buildroot}%{_includedir}/

rm -rf %{buildroot}%{_libdir}/xchat/plugins/*.la

%post
%update_menus

%if %build_dbus
export GCONF_CONFIG_SOURCE=`gconftool-2 --get-default-source`
gconftool-2 --makefile-install-rule %{_sysconfdir}/gconf/schemas/apps_xchat_url_handler.schemas > /dev/null

%preun 
if [ "$1" = "0" -a -x %{_bindir}/gconftool-2 ]; then
  export GCONF_CONFIG_SOURCE=`gconftool-2 --get-default-source`
  gconftool-2 --makefile-uninstall-rule %{_sysconfdir}/gconf/schemas/apps_xchat_url_handler.schemas > /dev/null
fi
%endif

%postun
%clean_menus

%clean
rm -fr $RPM_BUILD_ROOT

%files -f xchat.lang
%defattr(-,root,root)
%doc README ChangeLog faq.html COPYING plugins/plugin20.html
%{_bindir}/xchat
%{_datadir}/applications/xchat.desktop
%{_datadir}/dbus-1/services/org.xchat.service.service
%{_datadir}/pixmaps/xchat.png
%_menudir/*
%_iconsdir/%iconname
%_liconsdir/%iconname
%_miconsdir/%iconname  
%dir %{_libdir}/xchat/plugins
%dir %{_libdir}/xchat
%{_sysconfdir}/gconf/schemas/apps_xchat_url_handler.schemas

%files devel
%defattr(-,root,root)
%{_includedir}/xchat-plugin.h

%if %build_perl
%files perl
%defattr(-,root,root)
%doc README
%{_libdir}/xchat/plugins/perl.so
%endif

%if %build_python
%files python
%defattr(-,root,root)
%doc README
%{_libdir}/xchat/plugins/python.so
%endif

%if %build_tcl
%files tcl
%defattr(-,root,root)
%doc README
%{_libdir}/xchat/plugins/tcl.so
%endif



%changelog
* Fri Jan 05 2007 Pascal Terjan <pterjan@mandriva.org> 2.8.0-1mdv2007.1
+ Revision: 104547
- 2.8.0
- add upstream patch fixing /back
- add a patch to provide ISO-8859-15/UTF-8 hybrid charset

* Tue Dec 12 2006 Michael Scherer <misc@mandriva.org> 2.6.8-2mdv2007.1
+ Revision: 95301
- Rebuild for new python

* Tue Oct 17 2006 Pascal Terjan <pterjan@mandriva.org> 2.6.8-1mdv2007.0
+ Revision: 65946
- BuildRequires dbus-glib-devel instead of dbus-devel
- BuildRequires gettext-devel
- 2.6.8
- DBUS plugin is no longer a plugin
- Import xchat



* Fri Aug 11 2006 Pascal Terjan <pterjan@mandriva.org> 2.6.6-3mdv2007.0
- Fix crash in filechoser when dbus plugin loaded (P5)

* Tue Aug 01 2006 Frederic Crozat <fcrozat@mandriva.com> 2.6.6-2mdv2007.0
- Rebuild with latest dbus

* Tue Jul 18 2006 Pascal Terjan <pterjan@mandriva.org> 2.6.6-1mdv2007.0
- New release 2.6.6
- Drop P5
- Use libsexy for spellchecking

* Mon Jul 03 2006 Pascal Terjan <pterjan@mandriva.org> 2.6.4-3mdv2007.0
- Fix group of -devel subpackage
- Escape %% in changelog

* Mon Jul 03 2006 Pascal Terjan <pterjan@mandriva.org> 2.6.4-2mdv2007.0
- Remove invalid category from desktop file

* Thu Jun 08 2006 Pascal Terjan <pterjan@mandriva.org> 2.6.4-1mdv2007.0
- New release 2.6.4
- Fix source URL
- Add upstream patch to fix proxy (P5)
- Updated P0

* Sat May 06 2006 Pascal Terjan <pterjan@mandriva.org> 2.6.2-3mdk
- BuildRequires desktop-file-utils

* Thu May 04 2006 Frederic Crozat <fcrozat@mandriva.com> 2.6.2-2mdk
- Add categories to desktop file
- fix preun script

* Mon Mar 27 2006 Pascal Terjan <pterjan@mandriva.org> 2.6.2-1mdk
- 2.6.2
- don't ship .la from plugins

* Fri Jan 27 2006 Frederic Crozat <fcrozat@mandriva.com> 2.6.1-4mdk
- Rebuild with latest dbus

* Sun Jan 23 2006 Pascal Terjan <pterjan@mandriva.org> 2.6.1-3mdk
- rebuild for new perl

* Tue Jan 10 2006 Pascal Terjan <pterjan@mandriva.org> 2.6.1-2mdk
- Ease backports

* Sat Jan 07 2006 Pascal Terjan <pterjan@mandriva.org> 2.6.1-1mdk
- 2.6.1
- Drop Patch5 (fixed upstream)
- Drop xchat-text, broken again. Nobody should really miss it.
- Update Patch3

* Sun Jan 01 2006 Oden Eriksson <oeriksson@mandriva.com> 2.6.0-7mdk
- rebuilt to pickup new tcl lib

* Mon Nov 14 2005 Oden Eriksson <oeriksson@mandriva.com> 2.6.0-6mdk
- rebuilt against openssl-0.9.8a

* Mon Nov 07 2005 Christiaan Welvaart <cjw@daneel.dyndns.org> 2.6.0-5mdk
- add BuildRequires: libtool (for dbus plugin) GConf2

* Sat Nov 05 2005 Michael Scherer <misc@mandriva.org> 2.6.0-4mdk
- fix %%post script ( error when registering the handler ), thanks yanntech
- complete --with/--without

* Fri Nov 04 2005 Pascal Terjan <pterjan@mandriva.org> 2.6.0-3mdk
- add new options to the description

* Thu Nov 03 2005 Michael Scherer <misc@mandriva.org> 2.6.0-2mdk
- add mkrel
- add with and without option for perl/python/dbus/tcl
- place xchat-remote and the schema in the dbus package

* Thu Nov 03 2005 Pascal Terjan <pterjan@mandriva.org> 2.6.0-1mdk
- 2.6.0
- Drop patch5
- New Patch5 (fix fe-text building)
- New subpackage for dbus plugin
- Install gconf schemas

* Fri Sep 23 2005 Eskild Hustvedt <eskild@mandriva.org> 2.4.5-2mdk
- Fixed menu (bug #18808)

* Sun Sep 11 2005 Pascal Terjan <pterjan@mandriva.org> 2.4.5-1mdk
- 2.4.5
- patch5 from upstream fixing a crash
- Updated patch3

* Tue Jun 21 2005 Pascal Terjan <pterjan@mandriva.org> 2.4.4-1mdk
- 2.4.4
- become rpmbuildupdate aware

* Tue Jun 07 2005 Marcel Pol <mpol@mandriva.org> 2.4.3-4mdk
- update P3: s/mandrake/mandriva

* Thu May 19 2005 Pascal Terjan <pterjan@mandriva.org> 2.4.3-3mdk
- Rebuild for new perl

* Tue May 10 2005 Pascal Terjan <pterjan@mandriva.org> 2.4.3-2mdk
- Don't require specific version of python/tcl as the correct lib is already
  required. For perl we only require libperl.so so we really need to specify
  the version.

* Sat Apr 02 2005 Pascal Terjan <pterjan@mandrake.org> 2.4.3-1mdk
- 2.4.3

* Sun Mar 20 2005 Pascal Terjan <pterjan@mandrake.org> 2.4.2-1mdk
- 2.4.2
- Drop patch6

* Sat Jan 15 2005 Pascal Terjan <pterjan@mandrake.org> 2.4.1-4mdk
- fix P4

* Sat Dec 04 2004 Pascal Terjan <pterjan@mandrake.org> 2.4.1-3mdk
- really rebuild for new python...

* Sat Dec 04 2004 Pascal Terjan <pterjan@mandrake.org> 2.4.1-2mdk
- rebuild for new python

* Tue Nov 23 2004 Pascal Terjan <pterjan@mandrake.org> 2.4.1-1mdk
- 2.4.1
- fix URL handler for firefox (P4)
- fix xchat-text build (P5 from CVS)

* Mon Nov 15 2004 Pascal Terjan <pterjan@mandrake.org> 2.4.0-3mdk
- rebuild for new perl

* Mon Sep 06 2004 Marcel Pol <mpol@mandrake.org> 2.4.0-2mdk
- patch3, default server/channel set to FreeNode/#mandrake

* Mon Aug 16 2004 Pascal Terjan <pterjan@mandrake.org> 2.4.0-1mdk
- 2.4.0
- Drop patches 3 and 4

* Wed Aug 04 2004 Pascal Terjan <pterjan@mandrake.org> 2.0.10-3mdk
- New version of Patch4

* Mon Jul 26 2004 Pascal Terjan <pterjan@mandrake.org> 2.0.10-2mdk
- Package xchat-plugin.h in a -devel

* Tue Jul 13 2004 Pascal Terjan <pterjan@mandrake.org> 2.0.10-1mdk
- 2.0.10
- Official patches for focus and completion (P3 and P4)
- Drop P1 (old completion no longer exists)

* Thu Jul 08 2004 Rafael Garcia-Suarez <rgarciasuarez@mandrakesoft.com> 2.0.9-3mdk
- Rebuild for new perl

* Thu Jun 10 2004 Pascal Terjan <pterjan@mandrake.org> 2.0.9-2mdk
- Rebuild for new python

* Sat Jun 05 2004 Pascal Terjan <pterjan@mandrake.org> 2.0.9-1mdk
- 2.0.9
- Drop patch3

* Tue Apr 27 2004 Pascal Terjan <pterjan@mandrake.org> 2.0.8-5mdk
- Apply patch to fix socks5 (only used in plf...)

* Tue Apr 20 2004 Pascal Terjan <pterjan@mandrake.org> 2.0.8-4mdk
- Add Patch2 to keep : as nick separator after completion
  (patch from Sunny Dubey <sunny@opencurve.org>)

* Tue Apr 06 2004 Michael Scherer <misc@mandrake.org> 2.0.8-3mdk 
- rebuild for new perl

* Sat Apr 03 2004 Pascal Terjan <pterjan@mandrake.org> 2.0.8-2mdk
- re-apply other people's changes :(

* Sat Apr 03 2004 Pascal Terjan <pterjan@mandrake.org> 2.0.8-1mdk
- 2.0.8

* Wed Jan 21 2004 Pixel <pixel@mandrakesoft.com> 2.0.7-6mdk
- rebuild for new perl

* Sun Jan 18 2004 Olivier Blin <blino@mandrake.org> 2.0.7-5mdk
- build the text frontend

* Sat Jan 03 2004 Abel Cheung <deaddog@deaddog.org> 2.0.7-4mdk
- Final touches on plf option

* Fri Jan 02 2004 Pascal Terjan <pterjan@mandrake.org> 2.0.7-3mdk
- BuildRequires ImageMagick (thanks Olivier Blin)

* Thu Jan 01 2004 Charles A Edwards <eslrahc@bellsouth.net> 2.0.7-2mdk
- set for plf build option
- drop icon sources and use ImageMagick

* Thu Jan 01 2004 Pascal Terjan <pterjan@mandrake.org> 2.0.7-1mdk
- 2.0.7
- rediff patch1
- drop patch2 (DCC)

* Mon Dec 15 2003 Pascal Terjan <CMoi@tuxfamily.org> 2.0.6-2mdk
- Apply patch to prevent remote crash through DCC

* Sat Nov 29 2003 Pascal Terjan <CMoi@tuxfamily.org> 2.0.6-1mdk
- 2.0.6

* Mon Nov 24 2003 Pascal Terjan <CMoi@tuxfamily.org> 2.0.5-4mdk
- Add Patch 1 to allow changing completion style in the UI
  (patch from Sunny Dubey <sunny@opencurve.org>)

* Tue Nov 11 2003 Pascal Terjan <CMoi@tuxfamily.org> 2.0.5-3mdk
- rebuild for new perl

* Tue Nov 04 2003 Pascal Terjan <CMoi@tuxfamily.org> 2.0.5-2mdk
- merge lost change from gwenole

* Tue Sep 30 2003 Pascal Terjan <CMoi@tuxfamily.org> 2.0.5-1mdk
- 2.0.5
- Drop patch (merged upstream)

* Tue Sep 23 2003 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.0.4-7mdk
- lib64 fixes

* Wed Sep  3 2003 Abel Cheung <deaddog@deaddog.org> 2.0.4-6mdk
- Fix python and tcl version detection
- Convert this spec to UTF-8
- Enable optional socks5 support via build switch

* Mon Sep 01 2003 Guillaume Rousse <guillomovitch@linux-mandrake.com> 2.0.4-5mdk
- fixed menu longtitle (fixed bug #4772)
- clean-up

* Mon Aug 11 2003 Frederic Crozat <fcrozat@mandrakesoft.com> 2.0.4-4mdk
- Fix perl/python/tcl plugins aka don't try to run libtoolize 
  since we don't use libtool 1.5 yet
- Don't strip plugins, it is not done automatically

* Mon Aug 11 2003 Guillaume Rousse <guillomovitch@linux-mandrake.com> 2.0.4-3mdk
- fixed cowsay plugin (aka applied perl ui patch, thanks to Olivier Blin <oliv.blin@laposte.net>)

* Mon Aug 11 2003 Guillaume Rousse <guillomovitch@linux-mandrake.com> 2.0.4-2mdk
- rediff patch0
- strip plugins

* Sun Aug 10 2003 Guillaume Rousse <guillomovitch@linux-mandrake.com> 2.0.4-1mdk
- 2.0.4
- spec cleanup
- disable patch0, doesn't match

* Thu Aug  7 2003 Daouda LO <daouda@mandrakesoft.com> 2.0.3-5mdk
- rebuild against latest python lib

* Sat Aug  2 2003 Pixel <pixel@mandrakesoft.com> 2.0.3-4mdk
- rebuild for new perl

* Wed Jul 30 2003 Pixel <pixel@mandrakesoft.com> 2.0.3-3mdk
- when requiring the perl-base used for building, include the epoch

* Sun Jul 27 2003 Per Øyvind Karlsen <peroyvind@sintrax.net> 2.0.3-2mdk
- rebuild
- don't list only %%{_iconsdir}/* in %%files list, xchat doesn't own those subdirectories

* Sun Jun 29 2003 Pascal Terjan <CMoi@tuxfamily.org> 2.0.3-1mdk
- 2.0.3

* Thu Jun 26 2003 Daouda LO <daouda@mandrakesoft.com> 2.0.2-3mdk
- rebuild against python-2.2.3

* Sun May 04 2003 Pascal Terjan <CMoi@tuxfamily.org> 2.0.2-2mdk
- fix dir ownership
- remove Buildrequires:	libgtk+-x11-2.0_0-devel

* Mon Apr 28 2003 Pascal Terjan <CMoi@tuxfamily.org> 2.0.2-1mdk
- 2.0.2
- drop tab patch, now it's an option
- add ownership for %%{_libdir}/xchat/

* Fri Apr 11 2003 Pascal Terjan <CMoi@tuxfamily.org> 2.0.1-3mdk
- violently disable tab dragging
- rebuild for new libtcl

* Sun Apr 06 2003 Yves Duret <yves@zarb.org> 2.0.1-2mdk
- Recreate gc's Patch: CTCP VERSION don't show kernel version.
- add buildrequires on libgtk+-x11-2.0_0-devel thx Marco Pratesi <marco@fitcom.it>

* Sun Mar 23 2003 Yves Duret <yves@zarb.org> 2.0.1-1mdk
- new upstream version.

* Thu Feb 13 2003 Yves Duret <yves@zarb.org> 2.0.0-1mdk
- 2.0.0 final.
- zh locales may not be here.

* Mon Jan 27 2003 Yves Duret <yves@zarb.org> 2.0.0-0.pre1.1mdk
- new upstream version 2.0.0pre1.
- added tcl plugin as xchat-tcl rpm.
- added doc to all plugins for S.A.S. rpmlint.

* Fri Jan 24 2003 Yves Duret <yves@zarb.org> 1.9.8-1mdk
- the long awaited 1.9 aka GTK2 based.
- nowadays specfile ie. (aka deush really sux):
  * add the missing install step !
  * remove useless buildrequires such as gcc!
  * let rpmhelper do his job (do not strip binary by hand)
  * remove useless rpm icon
  * remove traduction embedded into spec
  * put the menu entry into spec and no in a seperated file
  * use macros dir such as iconsdir
  * do not add useless perm info on file listing
  * add missing doc
  * use %%configure2_5x %%makeinstall_std
- splitted into xchat-perl and xchat-python.

* Thu Jan 23 2003 Daouda LO <daouda@mandrakesoft.com> 1.8.11-1mdk
- release 1.8.11
   o Updated locales (Turkish, Swedish, Spanish)
   o Fixed /ME in dialog windows.
   o Support up to 4GB files in DCC (previously 2GB).
   o Fixed random /part reasons not working.
   o Fixed possible crash when receiving a message from a channel that
     was already parted.
   o Updated included intl/ to 0.10.38.
   o Updated build environment to autoconf 2.53.
   o Fixed tabcompletion crash on very large channels.
   o Fixed glibc 2.3.x regexp channel-list window crash.
   o Don't leak memory on /unloadall.
   o win32: convert \ and | to _ when receiving filenames with nick.
   o win32: don't use TerminateThread(), which leaks the stack.

* Fri Nov 15 2002 Daouda LO <daouda@mandrakesoft.com> 1.8.10-1mdk
- 1.8.10:
  o Fixed Russian translation errors (Anton Farygin).
  o Included missing Polish po file.
  o Updated Traditional Chinese translation (Kevin Peng).
  o Updated Catalan translation (Antoni Bella).
  o Added Vietnamese translation (pclouds).
  o Fixed crash on large notify list.
  o xtext: minor speedup tweaks.
  o xtext: fixed copy on Solaris (don't use "CLIPBOARD" atom).
  o Fixed /query #foo, /join #foo crash.
  o win32: added (slow) tinted transparency.
  o Added mIRC's passive dcc support, receiving only (Richard Fuchs).
  o Added basic HTTP proxy authentication support (Anton Voloshin).
  o Don't open window beyond the size of virtual desktop size (Jason Wies).

- obsoleted patch 11 (missing pl po file)
- xpm2png'ized icons.
- make rpmlint happier.
- strip binaries

* Mon Aug  5 2002 Guillaume Cottenceau <gc@mandrakesoft.com> 1.8.9-3mdk
- rebuild for threaded perl

* Tue Jul  9 2002 Guillaume Cottenceau <gc@mandrakesoft.com> 1.8.9-2mdk
- rebuild for new perl

* Thu May 23 2002 Thierry Vignaud <tvignaud@mandrakesoft.com> 1.8.9-1mdk
- new release
- enable python support
- support hebrew and japanese
- use gnome-panel
- support ipv6
- explicitely requires libpanel-applet-devel
- explicitely requires libpython-devel
- enable GNOME support : fix pixmaps missing, key bindings, and other fairly
  important features no longer working [Patch5]
- use sysconf to detect cpus [Patch6]
- libpanel_applet really is libpanel-applet [Patch10]
- pl translation isn't there [Patch11]

* Tue May 07 2002 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 1.8.8-2mdk
- Automated rebuild in gcc3.1 environment

* Sat Mar 09 2002 Geoffrey Lee <snailtalk@mandrakesoft.com> 1.8.8-1mdk
- 1.8.8 out for everyone's pleasure.

* Wed Feb 27 2002 Geoffrey Lee <snailtalk@mandrakesoft.com> 1.8.7-2mdk
- Rebuild.

* Thu Jan 10 2002 Geoffrey Lee <snailtalk@mandrakesoft.com> 1.8.7-1mdk
- The latest and shiniest 1.8.7.
- Regenerate Patch0 (CTCP don't show kernel version patch).

* Wed Jan  9 2002 Stefan van der Eijk <stefan@eijk.nu> 1.8.6-3mdk
- rebuild against python 2.2
- BuildRequires

* Tue Dec 18 2001 Geoffrey Lee <snailtalk@mandrakesoft.com> 1.8.6-2mdk
- Print less with CTCP version (gege).

* Thu Nov 29 2001 Geoffrey Lee <snailtalk@mandrakesoft.com> 1.8.6-1mdk
- Make a wonderful 1.8.6 RPM for download.

* Sun Oct 28 2001 Geoffrey Lee <snailtalk@mandrakesoft.com> 1.8.5-1mdk
- Presenting the all-new 1.8.5.

* Sun Sep 30 2001 Geoffrey Lee <snailtalk@mandrakesoft.com> 1.8.4-1mdk
- Presenting the latest 1.8.4.

* Sat Sep 28 2001 Geoffrey Lee <snailtalk@mandrakesoft.com> 1.8.3-1mdk
- Presenting the newest xchat 1.8.3.

* Sun Aug 05 2001 Geoffrey Lee <snailtalk@mandrakesoft.com> 1.8.2-1mdk
- Bump out 1.8.2 for everyone.

* Sat Aug  4 2001 Pixel <pixel@mandrakesoft.com> 1.8.1-2mdk
- add require the perl-base used for building (the libperl.so auto-require is not enough)

* Fri Jul 13 2001 Geoffrey Lee <snailtalk@mandrakesoft.com> 1.8.1-1mdk
- Put the very new and shiny 1.8.1 into cooker.

* Wed Jun 27 2001 Geoffrey Lee <snailtalk@mandrakesoft.com> 1.8.0-1mdk
- Put the very cool 1.8.0 out for cooker.
- Make it require gdk-pixbuf-devel when you build it.

* Sun Jun 24 2001 Stefan van der Eijk <stefan@eijk.nu> 1.7.8-3mdk
- BuildRequires: db1-devel
- BuildRequires: perl-devel
- Removed BuildRequires: audiofile-devel
- Removed BuildRequires: esound-devel
- Removed BuildRequires: imlib-devel
- Removed BuildRequires: ORBit-devel
- Removed BuildRequires: XFree86-devel

* Sat Jun 23 2001 Geoffrey Lee <snailtalk@mandrakesoft.com> 1.7.8-2mdk
- Include xchat-text (David Walluck).
- Requires python and BuildRequires python-devel (David Walluck).

* Fri Jun 22 2001 Geoffrey Lee <snailtalk@mandrakesoft.com> 1.7.8-1mdk
- Put 1.7.8 out for everyone.

* Fri Jun 14 2001 Geoffrey Lee <snailtalk@mandrakesoft.com> 1.7.7-1mdk
- The freshly baked 1.7.7 aka 1.8.0pre1 is out for cooker users.
- s/Copyright/License/;
- Silently remove the xchat-1.5.10 fontset patch, from testing it seems
  that it is no longer needed.
  
* Fri Apr 27 2001 Frederic Lepied <flepied@mandrakesoft.com> 1.6.4-5mdk
- enable ssl
- python 2.1

* Tue Mar 27 2001 Geoffrey Lee <snailtalk@mandrakesoft.com> 1.6.4-4mdk
- Make sure that .mo files are installed everytime.
- Fix zh_CN locale.

* Sun Mar 25 2001 Geoffrey Lee <snailtalk@mandrakesoft.com> 1.6.4-3mdk
- Include the .mo files (why the hell have they been missed?!!).

* Sun Feb 18 2001 Geoffrey Lee <snailtalk@mandrakesoft.com> 1.6.4-2mdk
- Change some stuff from the recommendation of xchat's author (zed@linux.com):
  - Remove the find and perl replacement expression, it is not needed anymore.
  - Correct the URL in the Source tag.
  - Don't enable socks in ./configure.

* Mon Feb 12 2001 Geoffrey Lee <snailtalk@mandrakesoft.om> 1.6.4-1mdk
- New and shiny source 1.6.4 out for general consumption.
- Remove --disalbe-textfe.

* Mon Jan  1 2001 Stefan van der Eijk <s.vandereijk@chello.nl> 1.6.2-1mdk
- shiny new version: 1.6.2
- add configure option --disable-textfe ; because of nasty python2 problem

* Wed Nov 15 2000 Geoffrey Lee <snailtalk@mandrakesoft.com> 1.6.0-1mdk
- new and shiny source bumped into cooker.

* Wed Nov 08 2000 Daouda Lo <daouda@mandrakesoft.com> 1.5.11-1mdk
- release

* Mon Nov 06 2000 Daouda Lo <daouda@mandrakesoft.com> 1.5.10-1mdk
- new release (gcc2.96 build)
- repatch fontset

* Thu Sep 07 2000 Alexandre Dussart <adussart@mandrakesoft.com> 1.4.3-2m
- Use find_lang.

* Mon Aug 28 2000 Geoffrey Lee <snailtalk@mandrakesoft.com. 1.4.3-1mdk
- rebuild for new version (security fix.)
- macrosifications.
- fix the installation of LC_MESSAGES.

* Mon Aug 07 2000 Frederic Lepied <flepied@mandrakesoft.com> 1.4.2-2mdk
- automatically added BuildRequires

* Tue Jun 13 2000 Alexandre Dussart <adussart@mandrakesoft.com> 1.4.2-1mdk
- 1.4.2

* Thu Apr 20 2000 Guillaume Cottenceau <gc@mandrakesoft.com> 1.4.1-3mdk
- fixed larger icon
- fixed menu postun
- removed useless gnome desktop entry

* Fri Apr 14 2000 Guillaume Cottenceau <gc@mandrakesoft.com> 1.4.1-2mdk
- add menu entry with icon

* Sat Apr 1  2000 Jerome Dumonteil <jd@mandrakesoft.com>
- fix group
- add menu
- version 1.4.1

* Fri Feb 11 2000 Geoffrey Lee <snailtalk@linux-mandrake.com>
- 1.4 

* Sun Feb 06 2000 Pablo Saratxaga <pablo@mandrakesoft.com> 1.3.12-2mdk
- added patch for fontset support (asiatic languages use fontsets)
- added the language catalogs to the %%files section

* Thu Jan 27 2000 Alexandre Dussart <adussart@mandrakesoft.com>
- 1.3.12

* Fri Jan 14 2000 Alexandre Dussart <adussart@mandrakesoft.com>
- 1.3.10

* Wed Dec 08 1999 Alexandre Dussart <adussart@mandrakesoft.com>
- 1.3.8(official now ;)

* Fri Nov 26 1999 Alexandre Dussart <adussart@mandrakesoft.com>
- 1.3.8
- Updated source URL.

* Wed Nov 10 1999 Alexandre Dussart <adussart@mandrakesoft.com>
- 1.3.7(fix many bugs)

* Fri Oct  29 1999 Alexandre Dussart <adussart@mandrakesoft.com>
- 1.3.5
- Updated URL. 
- Updated doc section(added AUTHORS and xchat.sgml)
- Added fr description.

* Thu Oct  7 1999 Chmouel Boudjnah <chmouel@mandrakesoft.com>
- 1.3.4.

* Wed Sep 15 1999 Daouda LO <daouda@mandrakesoft.com>
- 1.2.0

* Mon Aug 16 1999 Thierry Vignaud <tvignaud@mandrakesoft.com>
- 1.1.8

* Fri Aug 13 1999 Thierry Vignaud <tvignaud@mandrakesoft.com>
- 1.1.7

* Tue Aug 03 1999 Axalon Bloodstone <axalon@linux-mandrake.com>
- Why --disable-perl? (Removed)
- --enable-socks
- Icon for rpm
- 1.1.6 :
    * lots see /usr/doc/xchat-1.1.6/Changelog
    
* Mon Jul 26 1999 Axalon Bloodstone <axalon@linux-mandrake.com>
- Rebuild (2mdk) 

* Sat Jul 17 1999 Axalon Bloodstone <axalon@linux-mandrake.com>
- 1.1.2 :
    - Swedish translation update (Joel Rosdahl).
    - A better default popup menu (rm ~/.xchat/popup.conf if you want it)
    - Conference mode button - doesn't display join/parts.
    - Email addresses are clickable (in the main text area).
    - Hostnames and IP numbers are clickable (right click only).
    - If you joined two channels with the same people in them, userhost
      would mess up a bit - fixed.
    - Added /UNIGNORE
    - Added reverse ignore flag, eg:
      /ignore *!*@*.aol.com ALL
      /ignore myfriend!myfriend@*.aol.com ALL UNIGNORE
      (Would ignore everyone on AOL except myfriend).
    - Added Sort and Cancel buttons to ignore GUI.
    - Function Keys removed - "Edit Key Bindings" replaces it.
    - "Announce away messages" option (Sean 'Shaleh' Perry).
    - IRC::print takes multiple args (Bruce Ide).
    - Sending USERHOSTs on join are throttled so you don't excess flood
      on big channels.
    - Misc touchups.
    1.1.0 -> 1.1.1:
    - Text Events are hookable through perl (Matthias Urlichs).
      ( IRC::add_print_handler() )
    - A few palette stuff ups fixed (affected only non-zvt windows).
    - Major cleanups in text.c (TextEvents) (AGL).
    - Ignore GUI/Load/Save added (David H.rdeman).
    - USERHOST is issued on joining channels to find people's hostname.
    - Added perl command IRC::user_list (see perl.c).
    - Palette is saved in palatte.conf instead of xchat.conf.
					      

* Mon Jul 05 1999 Chmouel Boudjnah <chmouel@mandrakesoft.com>
- 1.1.0.
	 - Serbian translation (Zoltan Csala).
	 - URLs and nicknames are clickable (right click), still a bit
	   dodgy in zvt.
	 - Added IRC::print_with_channel( text, channel, servername )
	   (3rd arg is optional).
	 - Size/Pos/CPS are right justified in DCC windows.
	 - Updated French translations (Gissehel).
	 - Palette editor.
	 - 'Auto Open DCC CHAT window' option added (Javier Kohen).
	 - /Ignore added (no GUI yet).
	 - SaveBuffer in ZVT windows now works (Javier Kohen).
	 - Wildcard match in Channel List.
	 - DNS Program setting (use host, nslookup, or similar)
	 - "New Shell Tab" feature (requires GNOME).
	 - "Edit Key Bindings" feature (AGL).
	 - Dialog windows have a 'Chat' button (Fredrik Berglund).
	 - Trailing dots in url's are chopped.
	 - se.po renamed to sv.po
	 - Ran *.c and *.h through indent, should be nice and consistant now.
	 - Added recognition of WALLOPS from server.
	 - Updated Russian translation (Volosenkov Dmitry).
	 - Fixed a lockup bug (Affected FreeBSD and possibly others).

* Thu May  6 1999 Bernhard Rosenkraenzer <bero@mandrakesoft.com>
- Mandrake adaptions

* Sun Mar 28 1999 Michael Fulbright <drmike@redhat.com>
- version 0.9.4

* Thu Mar 18 1999 Michael Fulbright <drmike@redhat.com>
- version 0.9.3

* Mon Mar 8 1999 Michael Fulbright <drmike@redhat.com>
- version 0.9.2
